@@ -1,6 +1,6 @@
 package Astro::ADS::Paper;
 # ABSTRACT: A class for holding the document attributes for the results of a Search
-$Astro::ADS::Paper::VERSION = '1.91.1';
+$Astro::ADS::Paper::VERSION = '1.90';
 use Moo;
 
 use Carp;
@@ -9,6 +9,8 @@ use Mojo::Base -strict; # do we want -signatures
 use PerlX::Maybe;
 use Types::Standard qw( Int Str StrMatch ArrayRef HashRef Any ); # InstanceOf ConsumerOf
 
+no warnings 'experimental'; # suppress warning for native perl 5.36 try/catch
+
 #declare "Bibcode",
 #   was StrMatch[ qr{^\d{4} [\w.&]{5} [\d.]{4} [ELP-Z\d.] [\d.]{4} [A-Z]$}x ];
 #   now StrMatch[ qr{^\d{4} [\w.&]{5} [\d.]{4} [AELP-Z\d.] [\d.]{3}[B\d] [A-Z]$}x ];
@@ -85,7 +87,7 @@ Astro::ADS::Paper - A class for holding the document attributes for the results
 
 =head1 VERSION
 
-version 1.91.1
+version 1.90
 
 =head1 SYNOPSIS
 
