@@ -1,6 +1,6 @@
 package Astro::ADS::Result;
 # ABSTRACT: A class for the results of a Search
-$Astro::ADS::Result::VERSION = '1.91.1';
+$Astro::ADS::Result::VERSION = '1.90';
 use Moo;
 #extends 'Astro::ADS';
 
@@ -14,6 +14,8 @@ use Mojo::Util qw( quote );
 use PerlX::Maybe;
 use Types::Standard qw( Int Str ArrayRef HashRef Bool ); # InstanceOf ConsumerOf
 
+no warnings 'experimental'; # suppress warning for native perl 5.36 try/catch
+
 has [qw/q fq fl sort/] => (
     is       => 'rw',
     isa      => Str,
@@ -112,7 +114,7 @@ Astro::ADS::Result - A class for the results of a Search
 
 =head1 VERSION
 
-version 1.91.1
+version 1.90
 
 =head1 SYNOPSIS
 
@@ -159,13 +161,13 @@ If given an argument, it takes that as the number of rows to fetch.
 
 =over 4
 
-=item * L<Astro::ADS>
+=item *L<Astro::ADS>
 
-=item * L<Astro::ADS::Search>
+=item *L<Astro::ADS::Search>
 
-=item * L<ADS API|https://ui.adsabs.harvard.edu/help/api/>
+=item *L<ADS API|https://ui.adsabs.harvard.edu/help/api/>
 
-=item * L<Available fields for Results|https://ui.adsabs.harvard.edu/help/search/comprehensive-solr-term-list>
+=item *L<Available fields for Results|https://ui.adsabs.harvard.edu/help/search/comprehensive-solr-term-list>
 
 =back
 
