@@ -1,6 +1,6 @@
 package Astro::ADS::Search;
 # ABSTRACT: Queries the ADS Search endpoint and collects the results
-$Astro::ADS::Search::VERSION = '1.91.1';
+$Astro::ADS::Search::VERSION = '1.90';
 use Moo;
 extends 'Astro::ADS';
 with 'Astro::ADS::Role::ResultMapper';
@@ -15,6 +15,8 @@ use Mojo::Util qw( quote );
 use PerlX::Maybe;
 use Types::Standard qw( Int Str ArrayRef HashRef ); # InstanceOf ConsumerOf
 
+no warnings 'experimental'; # suppress warning for native perl 5.36 try/catch
+
 has [qw/q fq fl sort/] => (
     is       => 'rw',
 );
@@ -170,7 +172,7 @@ Astro::ADS::Search - Queries the ADS Search endpoint and collects the results
 
 =head1 VERSION
 
-version 1.91.1
+version 1.90
 
 =head1 SYNOPSIS
 
@@ -242,13 +244,13 @@ available with the author and title fields
 
 =over 4
 
-=item * L<Astro::ADS>
+=item *L<Astro::ADS>
 
-=item * L<Astro::ADS::Result>
+=item *L<Astro::ADS::Result>
 
-=item * L<ADS API|https://ui.adsabs.harvard.edu/help/api/>
+=item *L<ADS API|https://ui.adsabs.harvard.edu/help/api/>
 
-=item * L<Search Syntax|https://ui.adsabs.harvard.edu/help/search/search-syntax>
+=item *L<Search Syntax|https://ui.adsabs.harvard.edu/help/search/search-syntax>
 
 =back
 
